@@ -103,9 +103,9 @@ class QuakeMLFeed(Generic[T_FEED_ENTRY], ABC):
         self, method: str = "GET", headers=None, params=None
     ) -> Tuple[str, Optional[EventParameters]]:
         """Fetch QuakeML data from external source."""
+        url = self._fetch_url()
         try:
             timeout = aiohttp.ClientTimeout(total=self._client_session_timeout())
-            url = self._fetch_url()
             async with self._websession.request(
                 method, url, headers=headers, params=params, timeout=timeout
             ) as response:
@@ -199,7 +199,11 @@ class QuakeMLFeed(Generic[T_FEED_ENTRY], ABC):
         """Determine latest (newest) entry from the filtered feed."""
         if feed_entries:
             dates = sorted(
-                [entry.published for entry in feed_entries if entry.published],
+                [
+                    entry.creation_info.creation_time
+                    for entry in feed_entries
+                    if entry.creation_info and entry.creation_info.creation_time
+                ],
                 reverse=True,
             )
             if dates:
